@@ -227,6 +227,23 @@ def national_id(row):
     return(national_id)   
 
 
+#Letra del DNI
+
+#DNI
+
+letter_map = {0:'T', 1:'R', 2:'W', 3:'A', 4:'G', 5:'M', 
+              6:'Y', 7:'F', 8:'P', 9:'D', 10:'X', 11:'B', 
+              12:'N', 13:'J', 14:'Z', 15:'S', 16:'Q', 
+              17:'V', 18:'H', 19:'L', 20:'C', 21:'K', 22:'E'}
+
+def national_id_char(row):
+    letter = letter_map[int(id_num) % 23]
+    national_id_char= str(letter)
+       
+    return(national_id_char)   
+
+
+
 #          MATRICULA
 #-------------------------------------------------------------------------------------------------
 #Matricula de coche
